StyleParseErrorKind

Enum StyleParseErrorKind 

pub enum StyleParseErrorKind {
Show 26 variants BadUrlInDeclarationValueBlock, BadStringInDeclarationValueBlock, UnbalancedCloseParenthesisInDeclarationValueBlock, UnbalancedCloseSquareBracketInDeclarationValueBlock, UnbalancedCloseCurlyBracketInDeclarationValueBlock, PropertyDeclarationValueNotExhausted, UnexpectedDimension, MediaQueryExpectedFeatureName, MediaQueryExpectedFeatureValue, MediaQueryUnexpectedOperator, RangedExpressionWithNoValue, UnexpectedFunction, PropertySyntaxField(PropertySyntaxParseError), PropertyInheritsField(PropertyInheritsParseError), UnexpectedNamespaceRule, UnexpectedImportRule, DisallowedImportRule, UnexpectedCharsetRule, UnexpectedIdent, UnspecifiedError, UnexpectedTokenWithinNamespace, SelectorError(SelectorParseErrorKind), UnknownProperty, ExperimentalProperty, OtherInvalidValue, UnexpectedImportantDeclaration,
}
Errors that can be encountered while parsing CSS values.

Variants



BadUrlInDeclarationValueBlock

A bad URL token in a DVB.



BadStringInDeclarationValueBlock

A bad string token in a DVB.



UnbalancedCloseParenthesisInDeclarationValueBlock

Unexpected closing parenthesis in a DVB.



UnbalancedCloseSquareBracketInDeclarationValueBlock

Unexpected closing bracket in a DVB.



UnbalancedCloseCurlyBracketInDeclarationValueBlock

Unexpected closing curly bracket in a DVB.



PropertyDeclarationValueNotExhausted

A property declaration value had input remaining after successfully parsing.



UnexpectedDimension

An unexpected dimension token was encountered.



MediaQueryExpectedFeatureName

Missing or invalid media feature name.



MediaQueryExpectedFeatureValue

Missing or invalid media feature value.



MediaQueryUnexpectedOperator

A media feature range operator was not expected.



RangedExpressionWithNoValue

min- or max- properties must have a value.



UnexpectedFunction

A function was encountered that was not expected.



PropertySyntaxField(PropertySyntaxParseError)

Error encountered parsing a @property’s syntax descriptor



PropertyInheritsField(PropertyInheritsParseError)

Error encountered parsing a @property’s inherits descriptor.

TODO(zrhoffman, bug 1920365): Include the custom property name in error messages.



UnexpectedNamespaceRule

@namespace must be before any rule but @charset and @import



UnexpectedImportRule

@import must be before any rule but @charset



DisallowedImportRule

@import rules are disallowed in the parser.



UnexpectedCharsetRule

Unexpected @charset rule encountered.



UnexpectedIdent

The @property <custom-property-name> must start with --



UnspecifiedError

A placeholder for many sources of errors that require more specific variants.



UnexpectedTokenWithinNamespace

An unexpected token was found within a namespace rule.



SelectorError(SelectorParseErrorKind)

An error was encountered while parsing a selector



UnknownProperty

The property declaration was for an unknown property.



ExperimentalProperty

The property declaration was for a disabled experimental property.



OtherInvalidValue

The property declaration contained an invalid value.



UnexpectedImportantDeclaration

!important declarations are disallowed in @position-try or keyframes.